@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.12 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.13 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.12 2008/06/20 17:41:54 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.13 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowLst extends SyL_AdmFlow
@@ -202,7 +202,8 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
     function executeImport(&$data, &$context)
     {
         $data->addImport('ajax');
-        $context->setViewType('js.default');
+        $router =& $context->getRouter()
+        $router->setViewType('js.default');
     }
 
     /**
@@ -250,7 +251,8 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
             $data->set('header',  array());
             $data->set('columns', array());
             $data->apply('mb_convert_encoding', SYL_ENCODE_JS, SYL_ENCODE_INTERNAL);
-            $context->setViewType('json');
+            $router =& $context->getRouter()
+            $router->setViewType('json');
             return;
         }
         // ɽǡ
@@ -317,7 +319,8 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         $data->set('header',  $headers);
         $data->set('columns', $results);
         $data->apply('mb_convert_encoding', SYL_ENCODE_JS, SYL_ENCODE_INTERNAL);
-        $context->setViewType('json');
+        $router =& $context->getRouter()
+        $router->setViewType('json');
     }
 }
 
