@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.30 2008/09/29 14:41:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.31 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Action.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.30 2008/09/29 14:41:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.31 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -129,7 +129,7 @@ class SyL_ConfigActions extends SyL_Config
 
         if (SYL_CACHE && $enable_cache) {
             // åѤ
-            $key = SYL_APP_DIR . $this->context->getActionFile() . $this->context->getActionName();
+            $key = SYL_APP_DIR . $this->router->getActionFile() . $this->router->getActionName();
             $cache =& $this->getCache($key);
             if ($cache) {
                 // å夬Ǥʤäʥå奪֥Ȥ
@@ -152,7 +152,7 @@ class SyL_ConfigActions extends SyL_Config
 
         if (!isset($this->config[$this->action_key])) {
             // б륢ޥåԥ󥰤¸ߤʤ
-            trigger_error("[SyL error] Action mapping not found (" . $this->context->getActionFile() . ")", E_USER_ERROR);
+            trigger_error("[SyL error] Action mapping not found (" . $this->router->getActionFile() . ")", E_USER_ERROR);
         }
     }
 
@@ -196,11 +196,11 @@ class SyL_ConfigActions extends SyL_Config
 
             // URLǧ
             $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
-            if (preg_match('/^' . $reg . '$/', $this->context->getActionFile(), $matches)) {
+            if (preg_match('/^' . $reg . '$/', '/' . $this->router->getActionFile(), $matches)) {
                 $name  = $this->action_key;
                 // ǥեȥ
-                $class = $this->context->getClassName();
-                $file  = $this->context->getActionDir() . $this->context->getActionFile();
+                $class  = $this->router->getClassName();
+                $file   = $this->router->getActionDir() . $this->router->getActionFile();
                 // ǥե¸Ƚ
                 if (!is_file($file)) {
                     $class = SyL_Loader::convertClass(SYL_ACTION_BASE_CLASS);
@@ -223,7 +223,7 @@ class SyL_ConfigActions extends SyL_Config
 
                 $method_name = '';
                 if (isset($attribute['method'])) {
-                    $method_name = 'method:' . str_replace('{action}', $this->context->getActionName(), $attribute['method']);
+                    $method_name = 'method:' . str_replace('{action}', $this->router->getActionName(), $attribute['method']);
                 } else {
                     // ᥽åɤΥǥե
                     $method_name = 'method:' . $this->default_method;
