@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.20 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.21 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.20 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.21 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigComponents extends SyL_Config
@@ -88,8 +88,7 @@ class SyL_ConfigComponents extends SyL_Config
         if (SYL_CACHE && $enable_cache) {
             // åѤ
             $key = SYL_PROJECT_DIR;
-            $cache =& $this->getCache($key);
-            if ($cache) {
+            if ($cache =& $this->getCache($key)) {
                 // å夬Ǥʤäʥå奪֥Ȥ
                 parent::parseXml();
                 $cache->write($this->config);
