@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.20 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.21 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.20 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.21 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigDefines extends SyL_Config
@@ -103,6 +103,7 @@ class SyL_ConfigDefines extends SyL_Config
                 // å夬Ǥʤäʥå奪֥Ȥ
                 parent::parseXml();
                 // å¸
+                //$cache->setSerialize(false);
                 $cache->write($this->config);
             }
         } else {
@@ -153,13 +154,13 @@ class SyL_ConfigDefines extends SyL_Config
      *
      * @access private
      * @param array ޥå
-     @ return mixed ޥå
+     * @return mixed ޥå
      */
     function replaceConstants($matches)
     {
         if (isset($this->config[$matches[1]])) {
             return $this->config[$matches[1]];
-        } else if (defined($matches[1])) {
+    } else if (defined($matches[1])) {
             return constant($matches[1]);
         } else {
             return '{' . $matches[1] . '}';
