@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.22 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.23 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.22 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.23 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
@@ -124,7 +124,7 @@ class SyL_ConfigFilters extends SyL_Config
         if (count($this->file_names) > 0) {
             if (SYL_CACHE && $enable_cache) {
                 // åѤ
-                $key = SYL_APP_DIR . $this->context->getActionFile();
+                $key = SYL_APP_DIR . $this->router->getActionFile();
                 $cache =& $this->getCache($key);
                 if ($cache) {
                     // å夬Ǥʤäʥå奪֥Ȥ
@@ -149,7 +149,7 @@ class SyL_ConfigFilters extends SyL_Config
      */
     function getElement($current_path, $attribute, $text)
     {
-        static $name  = '';
+        static $name = '';
         static $method_name = '';
 
 //echo $current_path . "<br>";
@@ -164,7 +164,8 @@ class SyL_ConfigFilters extends SyL_Config
 
             // ̾ǧ
             $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
-            if (preg_match('/^' . $reg . '$/', $this->context->getActionFile())) {
+            // եѥ롼֥
+            if (preg_match('/^' . $reg . '$/', '/'.$this->router->getActionFile())) {
                 $name = $attribute['name'];
                 $this->config[$name]['type']      = 'filter';
                 $this->config[$name]['class']     = $attribute['class'];
