@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.12 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.13 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.12 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.13 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigLayouts extends SyL_Config
@@ -72,7 +72,7 @@ class SyL_ConfigLayouts extends SyL_Config
     {
         if (SYL_CACHE && $enable_cache) {
             // åѤ
-            $key = SYL_APP_DIR . $this->context->getActionFile();
+            $key = SYL_APP_DIR . $this->router->getActionFile();
             $cache =& $this->getCache($key);
             if ($cache) {
                 // å夬Ǥʤäʥå奪֥Ȥ
@@ -86,7 +86,7 @@ class SyL_ConfigLayouts extends SyL_Config
 
         if (!isset($this->config['file'])) {
             // б쥤ȥޥåԥ󥰤¸ߤʤ
-            trigger_error("[SyL error] Layout mapping not found (Layout name: " . $this->context->getLayoutName() . ")", E_USER_ERROR);
+            trigger_error("[SyL error] Layout mapping not found (Layout name: " . $this->router->getLayoutName() . ")", E_USER_ERROR);
         }
     }
 
@@ -119,7 +119,7 @@ class SyL_ConfigLayouts extends SyL_Config
             }
 
             // 쥤̾Ƚ
-            if ($attribute['name'] == $this->context->getLayoutName()) {
+            if ($attribute['name'] == $this->router->getLayoutName()) {
                 $layout = 1;
                 $this->config['file']       = $attribute['file'];
                 $this->config['templates']  = array();
@@ -147,7 +147,8 @@ class SyL_ConfigLayouts extends SyL_Config
                     return;
                 }
                 $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
-                if (preg_match('/^' . $reg . '$/', $this->context->getActionFile())) {
+                // եѥ롼֥
+                if (preg_match('/^' . $reg . '$/', '/' . $this->router->getActionFile())) {
                     $parameter = 1;
                 }
                 break;
