@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.12 2008/09/23 09:06:16 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.13 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,18 +44,11 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.12 2008/09/23 09:06:16 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.13 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextJs extends SyL_Context
 {
-    /**
-     * ꥯȥ֥
-     * 
-     * @access private
-     * @var object
-     */
-    var $request = null;
     /**
      * ӥ塼
      * 
@@ -75,10 +68,8 @@ class SyL_ContextJs extends SyL_Context
         // JSݡȽ
         if ($data->getImport()) {
             $this->is_execute = false;
-            $this->setViewType('js.default');
-        } else {
-            parent::SyL_Context($data);
         }
+        parent::SyL_Context($data);
     }
 
     /**
@@ -89,10 +80,7 @@ class SyL_ContextJs extends SyL_Context
      */
     function &getRequest()
     {
-        if ($this->request == null) {
-            $this->request =& SyL_Request::singleton();
-        }
-        return $this->request;
+        return SyL_Request::singleton();
     }
 
     /**
