@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.12 2008/09/29 14:41:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.13 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_ContextJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.12 2008/09/29 14:41:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.13 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextWeb extends SyL_ContextJs
@@ -56,127 +56,6 @@ class SyL_ContextWeb extends SyL_ContextJs
      * @var string
      */
     var $view_type = 'default';
-    /**
-     * ƥץ졼ȥե
-     * 
-     * @access private
-     * @var string
-     */
-    var $template_file = '';
-    /**
-     * 쥤̾
-     * 
-     * @access private
-     * @var string
-     */
-    var $layout_name = '';
-
-    /**
-     * 󥹥ȥ饯
-     *
-     * @access public
-     * @param object ǡ֥
-     */
-    function SyL_ContextWeb(&$data)
-    {
-        parent::SyL_ContextJs($data);
-
-        if (!$data->getImport()) {
-            $router =& SyL_Router::singleton();
-            $this->setTemplateFile($router->getTemplateFile());
-            $layout_name = $router->getLayoutName();
-            if ($layout_name !== '') {
-                $this->setLayoutName($layout_name);
-            }
-        }
-    }
-
-    /**
-     * ƥץ졼ȥե򥻥å
-     * 
-     * @access public
-     * @param string ƥץ졼ȥե
-     */
-    function setTemplateFile($template_file)
-    {
-        $this->template_file = $template_file;
-    }
-
-    /**
-     * ƥץ졼ȥե򥻥åȡʥإѡ
-     * ǻ
-     * 
-     * @access public
-     * @param string ƥץ졼ȥե
-     */
-    function setTemplate($template)
-    {
-        $pos = strrpos($this->template_file, '.');
-        if ($pos === false) {
-            trigger_error("[SyL error] Template file extension not found ({$this->template_file})", E_USER_ERROR);
-        }
-        $ext = substr($this->template_file, $pos+1);
-        $this->template_file = SyL_Loader::convertPath($template, $ext);
-    }
-
-    /**
-     * ƥץ졼ȥǥ쥯ȥ
-     * 
-     * @access public
-     * @return string ƥץ졼ȥǥ쥯ȥ
-     */
-    function getTemplateDir()
-    {
-        return $this->template_dir . '/';
-    }
-
-    /**
-     * ƥץ졼ȥե
-     * 
-     * @access public
-     * @param bool 404顼ưե饰
-     * @return string ƥץ졼ȥե
-     */
-    function getTemplateFile($trigger_error_404=true)
-    {
-        $template_dir  = $this->getTemplateDir();
-        $template_file = $this->template_file;
-        if (preg_match('/^(\\\\|\/)(.+)$/', $template_file, $matches)) {
-            $template_file = $matches[2];
-        }
-
-        // ǥХå - ƥץ졼Ȥξ
-        SyL_Loggers::debug("Template dir: {$template_dir} file: {$template_file}");
-
-        // ƥץ졼ȥե¸ߥå
-        if ($trigger_error_404 && !is_file($template_dir . $template_file)) {
-            SyL_Loggers::warn("Template file not found dir: {$template_dir} file: {$template_file}");
-            SyL_Response::forward404();
-        }
-        return $template_file;
-    }
-
-    /**
-     * 쥤̾򥻥å
-     *
-     * @access public
-     * @return string 쥤̾
-     */
-    function setLayoutName($layout_name)
-    {
-        $this->layout_name = $layout_name;
-    }
-
-    /**
-     * 쥤̾
-     *
-     * @access public
-     * @return string 쥤̾
-     */
-    function getLayoutName()
-    {
-        return $this->layout_name;
-    }
 
     /**
      * ɥե򥻥å
@@ -209,7 +88,7 @@ class SyL_ContextWeb extends SyL_ContextJs
      */
     function setDownloadData($data, $filename='', $type='application/octet-stream')
     {
-        $this->setViewType('download');
+        $this->router->setViewType('download');
         $this->setParameter('_download_name', $filename);
         $this->setParameter('_download_type', $type);
         $this->setParameter('_download_data', $data);
@@ -227,7 +106,7 @@ class SyL_ContextWeb extends SyL_ContextJs
         if (!$type) {
             $size = getimagesize($file);
             if (!$size || !isset($size['mime'])) {
-                trigger_error("[SyL error] Image mime unable to get from getimagesize function ($file)", E_USER_ERROR);
+                trigger_error("[SyL error] Image mime unable to get from getimagesize function ({$file})", E_USER_ERROR);
             }
             $type = $size['mime'];
         }
@@ -247,7 +126,7 @@ class SyL_ContextWeb extends SyL_ContextJs
      */
     function setDisplayImageData($data, $type='')
     {
-        $this->setViewType('image');
+        $this->router->setViewType('image');
         $this->setParameter('_image_type',  $type);
         $this->setParameter('_image_data',  $data);
     }
@@ -261,7 +140,7 @@ class SyL_ContextWeb extends SyL_ContextJs
      */
     function setDisplayXml($rss_object, $type='text/xml')
     {
-        $this->setViewType('xml');
+        $this->router->setViewType('xml');
         $this->setParameter('_xml_type',    $type);
         $this->setParameter('_xml_object',  $rss_object);
     }
@@ -275,7 +154,7 @@ class SyL_ContextWeb extends SyL_ContextJs
      */
     function setDisplayRss($rss_object, $type='text/xml')
     {
-        $this->setViewType('rss');
+        $this->router->setViewType('rss');
         $this->setParameter('_rss_type',    $type);
         $this->setParameter('_rss_object',  $rss_object);
     }
@@ -288,7 +167,7 @@ class SyL_ContextWeb extends SyL_ContextJs
      */
     function setRedirectUrl($url)
     {
-        $this->setViewType('redirect');
+        $this->router->setViewType('redirect');
         $this->setParameter('_redirect_url', $url);
     }
 }
