@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataCmd.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataCmd.php,v 1.7 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataCmd.php,v 1.6 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataCmd.php,v 1.7 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataCmd extends SyL_Data
@@ -67,7 +67,7 @@ class SyL_DataCmd extends SyL_Data
                     $parameters[$tmp_args[0]] = array($tmp);
                 }
                 $tmp_arg = null;
-            } else if ((substr($arg, 0, 1) == '-') && (strlen($arg) > 1)) {
+            } else if (($arg[0] == '-') && (strlen($arg) > 1)) {
                 $tmp_arg = substr($arg, 1);
                 if (isset($parameters[$tmp_arg])) {
                     $parameters[$tmp_arg][] = null;
