@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.27 2008/09/29 14:41:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.28 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.27 2008/09/29 14:41:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.28 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -58,7 +58,7 @@ class SyL_ErrorWeb extends SyL_Error
      *
      * @access public
      */
-    function forward404Detail()
+    function forwardFileNotFoundDetail()
     {
         // 쥯Ƚ
         if (preg_match('/^(redirect\:\:)(.+)$/', SYL_ERROR_FORWARD_FILE_404, $matches)) {
