@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.9 2008/09/29 14:41:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.10 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.9 2008/09/29 14:41:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.10 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorXmlrpc extends SyL_Error
@@ -49,7 +49,7 @@ class SyL_ErrorXmlrpc extends SyL_Error
      *
      * @access public
      */
-    function forward404Detail()
+    function forwardFileNotFoundDetail()
     {
         $referer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '(none)';
         SyL_Loggers::warn("404 Not Found. from {$referer}");
