@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.22 2008/09/29 14:41:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.23 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.22 2008/09/29 14:41:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.23 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterParameter extends SyL_Router
@@ -71,23 +71,21 @@ class SyL_RouterParameter extends SyL_Router
         switch (count($pathinfo)) {
         case 0:
             $this->action_method = '';
-            $this->action_file   = '/' . ucfirst($this->action_file_default);
+            $this->setActionFile(ucfirst($this->action_file_default));
             break;
         case 1:
             $this->action_method = array_pop($pathinfo);
-            $this->action_file   = '/' . ucfirst($this->action_file_default);
+            $this->setActionFile(ucfirst($this->action_file_default));
             break;
         default:
             $this->action_method = array_pop($pathinfo);
-            $this->action_file   = '/' . implode('/', array_map('ucfirst', $pathinfo)) . $this->exe_ext;
+            $this->setActionFile(implode('/', array_map('ucfirst', $pathinfo)) . $this->exe_ext);
             array_pop($pathinfo); // ե̾
             break;
         }
 
         // ƥץ졼ȥե
-        $this->template_file = substr($this->action_file, 0, intval('-' . strlen($this->exe_ext))) . SYL_ROUTER_URL_EXT;
-        // 饹ե
-        $this->action_class = $this->createActionClass($this->action_file);
+        $this->setTemplateFile(substr($this->action_file, 0, intval('-' . strlen($this->exe_ext))) . SYL_ROUTER_URL_EXT);
     }
 
 }
