@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.22 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.23 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.22 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.23 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -55,8 +55,8 @@ class SyL_RouterPathinfo extends SyL_Router
     /**
      * ܾ󥪥֥ȤΥץѥƥ
      *
-     * @access protected
-     * @param object ꥯȥ֥
+     * @access public
+     * @param object ǡ֥
      */
     function createActionInfo(&$data)
     {
@@ -65,14 +65,14 @@ class SyL_RouterPathinfo extends SyL_Router
 
         if ($pathinfo == '') {
             $this->action_method = '';
-            $this->action_file   = '/' . ucfirst($this->action_file_default);
+            $this->setActionFile(ucfirst($this->action_file_default));
         } else if (substr($pathinfo, -1) == '/') {
             $this->action_method = '';
-            $this->action_file   = implode('/', array_map('ucfirst', explode('/', $pathinfo))) . $this->action_file_default;
+            $this->setActionFile(implode('/', array_map('ucfirst', explode('/', $pathinfo))) . $this->action_file_default);
         } else {
             // ĥȽ
             if ($this->url_ext && !preg_match('/^(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo)) {
-                SyL_Response::forward404();
+                SyL_Response::forwardFileNotFound();
             }
             $pathinfo_file  = basename($pathinfo);
             $pathinfo_dir   = dirname($pathinfo);
@@ -89,35 +89,36 @@ class SyL_RouterPathinfo extends SyL_Router
 
             // ƬʸѴ
             $pathinfo_dir = implode('/', array_map('ucfirst', explode('/', $pathinfo_dir)));
-
+            $action_file = '';
             if (count($pathinfo_files) == 2) {
                 if (($this->action_delimiter == '.') && ($this->url_ext == ('.' . $pathinfo_files[1]))) {
                     // ᥽åɤʤ
                     $this->action_method = '';
-                    $this->action_file = $pathinfo_dir . ucfirst($pathinfo_files[0]) . $this->exe_ext;
+                    $action_file = $pathinfo_dir . ucfirst($pathinfo_files[0]) . $this->exe_ext;
                 } else {
                     $this->action_method = ucfirst($pathinfo_files[0]);
                     if (preg_match('/^(.+)(' . preg_quote($this->url_ext) . '|' . preg_quote($this->exe_ext) . ')$/', $pathinfo_files[1], $matches)) {
                         // ᥽åɤ
-                        $this->action_file = $pathinfo_dir . ucfirst($matches[1]) . $this->exe_ext;
+                        $action_file = $pathinfo_dir . ucfirst($matches[1]) . $this->exe_ext;
                     } else {
                         // ᥽åɤ
-                        $this->action_file = $pathinfo_dir . ucfirst($pathinfo_files[1]) . $this->exe_ext;
+                        $action_file = $pathinfo_dir . ucfirst($pathinfo_files[1]) . $this->exe_ext;
                     }
                 }
             } else {
                 // ᥽åɤʤ
                 $this->action_method = '';
                 if (preg_match('/^(.+)(' . preg_quote($this->url_ext) . '|' . preg_quote($this->exe_ext) . ')$/', $pathinfo_files[1], $matches)) {
-                    $this->action_file = $pathinfo_dir . ucfirst($matches[1]) . $this->exe_ext;
+                    $action_file = $pathinfo_dir . ucfirst($matches[1]) . $this->exe_ext;
                 } else {
-                    $this->action_file = $pathinfo_dir . ucfirst($pathinfo_files[1]) . $this->exe_ext;
+                    $action_file = $pathinfo_dir . ucfirst($pathinfo_files[1]) . $this->exe_ext;
                 }
             }
+            $this->setActionFile($action_file);
         }
 
         // ƥץ졼ȥե
-        $this->template_file = substr($this->action_file, 0, intval('-' . strlen($this->exe_ext))) . SYL_ROUTER_URL_EXT;
+        $this->setTemplateFile(substr($this->action_file, 0, intval('-' . strlen($this->exe_ext))) . SYL_ROUTER_URL_EXT);
 
         $action_method = null;
         // ᥽åͤѥ᡼Υ
@@ -139,13 +140,9 @@ class SyL_RouterPathinfo extends SyL_Router
             $this->action_method = ucfirst($action_method);
         }
 
-        // 饹ե
-        $this->action_class = $this->createActionClass($this->action_file);
-
 /*
 echo "action_method: " . $this->action_method . "<br>";
 echo "action_file: " . $this->action_file . "<br>";
-echo "class_name: " . $this->action_class . "<br>";
 echo "template file: " . $this->template_file  . "<br>";
 exit;
 */
