@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.21 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.22 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.21 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.22 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Config extends SyL_XmlReader
@@ -74,13 +74,6 @@ class SyL_Config extends SyL_XmlReader
      * @var int
      */
     var $default_priority = 5;
-    /**
-     * ƥȥ֥
-     * 
-     * @access protected
-     * @var object
-     */
-    var $context = null;
     /**
      * XMLե̾
      * 
@@ -95,6 +88,13 @@ class SyL_Config extends SyL_XmlReader
      * @var array
      */
     var $config = array();
+    /**
+     * 롼֥
+     * 
+     * @access private
+     * @var object
+     */
+    var $router = null;
 
     /**
      * 󥹥ȥ饯
@@ -132,14 +132,14 @@ class SyL_Config extends SyL_XmlReader
     }
 
     /**
-     * ƥȤ򥻥å
+     * 롼֥Ȥ򥻥å
      *
      * @access public
-     * @param object ƥȥ֥
+     * @param object 롼֥
      */
-    function setContext(&$context)
+    function setRouter(&$router)
     {
-        $this->context =& $context;
+        $this->router =& $router;
     }
 
     /**
@@ -185,13 +185,11 @@ class SyL_Config extends SyL_XmlReader
             }
         }
 
-        $cache =& SyL_Cache::factory(SYL_CACHE);
+        $cache =& SyL_Cache::factory('file');
         $cache->setPrefix(SYL_APP_NAME . '.');
         $cache->setKey($key);
         $cache->setMinModifyTime($mtime);
-        if (defined('SYL_CACHE_FILE_DIR') && SYL_CACHE_FILE_DIR) {
-            $cache->setCacheDir(SYL_CACHE_FILE_DIR . '/config/' . basename($this->file_names[0]) . '/');
-        }
+        $cache->setCacheDir(SYL_CACHE_FILE_DIR . '/config/' . basename($this->file_names[0]) . '/');
 
         //$cache->useIncludeCache();
 
