@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.30 2008/09/23 09:06:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.31 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,25 +44,11 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.30 2008/09/23 09:06:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.31 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
 {
-    /**
-     * ƥ
-     * 
-     * @access private
-     * @var array
-     */
-    var $config = array();
-    /**
-     * ץꥱ᥽å
-     * 
-     * @access private
-     * @var array
-     */
-    var $app_config = array();
     /**
      * ݡͥȥ֥ȳǼ
      * 
@@ -89,7 +75,7 @@ class SyL_Container
     function &singleton()
     {
         static $singleton;
-        if (!is_object($singleton)) {
+        if ($singleton == null) {
             $classname = __CLASS__;
             $singleton = new $classname();
         }
@@ -107,34 +93,33 @@ class SyL_Container
      */
     function raiseEvent($event, $config_type='', $component_name='')
     {
+        static $config = array();
+
         // ٥ȳϥ
         $this->log('debug', "{$event} event start");
 
         // եɤ߹
         if ($config_type) {
-            $this->config += $this->readConfig($config_type);
+            $config += $this->readConfig($config_type);
             // ̥ͥȽ
-            uasort($this->config, array(&$this, 'sortConfig'));
+            uasort($config, array(&$this, 'sortConfig'));
         }
-        // ݻ
-        $tmp_config =& $this->config;
 
         // ƥʤ
         if ($event == 'finalStream') {
-            //$this->log('debug', "$event event global config ..." . print_r($this->config, true));
-            //$this->log('debug', "$event event application config ..." . print_r($this->app_config, true));
+            //$this->log('debug', "$event event global config ..." . print_r($config, true));
         }
 /*
 echo "-------------- " . $event . " ---------------------------------------------------<br>";
 
 echo "<pre>";
-print_r($this->config);
+print_r($config);
 echo "</pre>";
 
 */
 
         // ݡͥȼ¹ԥ롼
-        foreach ($tmp_config as $name => $keys) {
+        foreach ($config as $name => $keys) {
             $classname = $keys['class'];
 
             // ٥ȤʤХå
@@ -152,7 +137,7 @@ echo "</pre>";
                 // ݡͥȤ
                 if (!$this->LoadLib($keys['file'])) {
                     // ٥Ⱥ
-                    $this->deleteEventConfig($name, $name, $event, $keys, $tmp_config);
+                    $this->deleteEventConfig($name, $name, $event, $keys, $config);
                     if ($keys['force']) {
                         trigger_error("[SyL error] Component include failed. file not found (" . SYL_INCLUDE_DIR . "/{$keys['file']} or " . SYL_PROJECT_LIB_DIR . "/{$keys['file']} or {$keys['file']})", E_USER_ERROR);
                     }
@@ -173,7 +158,7 @@ echo "</pre>";
                 // ֥Ⱥ
                 unset($component);
                 // ٥Ⱥ
-                $this->deleteEventConfig($name, $name, $event, $keys, $tmp_config);
+                $this->deleteEventConfig($name, $name, $event, $keys, $config);
             }
 
             foreach ($keys['args'] as $func => $args) {
@@ -269,7 +254,7 @@ echo "</pre>";
                         // ͽʤ᥽åɤμ¹Ԥϥ顼
                         if (class_exists('SyL_Response')) {
                             $this->log('warn', "Method injection failed: method not found (" . get_class($component) . ".{$funcs[1]})");
-                            SyL_Response::forward404();
+                            SyL_Response::forwardFileNotFound();
                         } else {
                             trigger_error("[SyL error] Method injection failed: method not found (" . get_class($component) . ".{$funcs[1]})", E_USER_ERROR);
                         }
@@ -303,7 +288,7 @@ echo "</pre>";
                 // ֥Ⱥ
                 unset($component);
                 // ٥Ⱥ
-                $this->deleteEventConfig($name, $func, $event, $keys, $tmp_config);
+                $this->deleteEventConfig($name, $func, $event, $keys, $config);
             }
         }
     }
@@ -317,18 +302,19 @@ echo "</pre>";
      */
     function readConfig($config_type)
     {
-        $reader =& SyL_Config::factory($config_type);
+        $config =& SyL_Config::factory($config_type);
         if ($this->isComponent('context')) {
-            $reader->setContext($this->getComponent('context'));
+            $context =& $this->getComponent('context');
+            $config->setRouter($context->getRouter());
         }
-        $reader->parseXml();
-        return $reader->getConfig();
+        $config->parseXml();
+        return $config->getConfig();
     }
 
     /**
      * ¹Խ̤ͥȤ˥Ȥ
      *
-     * @access public
+     * @access private
      * @param array ߤ
      * @param array 
      * @return object ݡͥȥ֥
@@ -399,28 +385,6 @@ echo "</pre>";
         }
     }
 
-    /**
-     * ƥͤ
-     *
-     * @access public
-     * @return array ƥ
-     */
-    function getConfig()
-    {
-        return $this->config;
-    }
-
-    /**
-     * ץꥱ᥽åͤ
-     *
-     * @access public
-     * @return array ץꥱ᥽å
-     */
-    function getAppConfig()
-    {
-        return $this->app_config;
-    }
-
     /**
      * ݡͥȤ
      *
