@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.10 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.11 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.10 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.11 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Data extends SyL_UtilProperty
@@ -383,7 +383,7 @@ class SyL_Data extends SyL_UtilProperty
      */
     function checkName($name)
     {
-        if (substr($name, 0, 1) == '_') {
+        if ($name[0] == '_') {
             trigger_error("[SyL error] Data property name invalid first char ({$name})", E_USER_ERROR);
         }
 
