@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.31 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.32 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.31 2008/07/10 15:17:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.32 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -191,7 +191,7 @@ class SyL_Error
      * @static
      * @access public
      */
-    function forward404()
+    function forwardFileNotFound()
     {
         // Хåե󥰥ꥢ
         if (!headers_sent() && (ob_get_level() > 0)) {
@@ -199,16 +199,16 @@ class SyL_Error
         }
 
         $error =& SyL_Error::getInstance();
-        $error->forward404Detail();
+        $error->forwardFileNotFoundDetail();
         exit;
     }
 
     /**
      * 404 Not Found ɽ
      *
-     * @access public
+     * @access abstract
      */
-    function forward404Detail()
+    function forwardFileNotFoundDetail()
     {
     }
 
@@ -303,11 +303,6 @@ class SyL_Error
         $error_trace = array();
         $i = 1;
         foreach (array_reverse($this->controller->getErrorTrace()) as $values) {
-            // 桼顼ϡtrigger_error״ؿʹߤӽ
-            // ¾Υ顼ϡerrorhandler״ؿʹߤӽ
-            if (isset($values['class']) && (strtolower($values['class']) == strtolower(get_class($this)))) {
-                break;
-            }
             $tmp = array();
             $tmp['no']   = $i++;
             $tmp['file'] = isset($values['file']) ? $values['file'] : '-';
@@ -318,6 +313,14 @@ class SyL_Error
                 $tmp['function'] = (isset($values['function']) && ($values['function'] != 'unknown')) ? $values['function'] : '-';
             }
             $error_trace[] = $tmp;
+
+            // 桼顼ϡtrigger_error״ؿʹߤӽ
+            // ¾Υ顼ϡSyL_Error::triggerץ᥽åɰʹߤӽ
+            if (isset($values['class']) && (strtolower($values['class']) == 'syl_error')) {
+                break;
+            } else if (isset($values['function']) && ($values['function'] == 'trigger_error')) {
+                break;
+            }
         }
 
         return array_reverse($error_trace);
@@ -423,13 +426,12 @@ class SyL_Error
             // SyLΥС
             $version     = SYL_VERSION;
             $version_php = PHP_VERSION;
-            $uname = php_uname();
+            $uname       = php_uname();
 
             $error_mail_subject = "SyL Framework Error Report - {$server} - {$date}";
             $error_mail_body = <<< EOF
-SyL Framework Error info.
+SyL Framework Error info. {$date}
 ----------------------------------------
-DATE: {$date}
 
 {$error_message}
 
@@ -440,31 +442,12 @@ EOF;
             // 
             SyL_Loggers::info("Error mail Type: "    . SYL_MAIL_TYPE);
             SyL_Loggers::info("Error mail Subject: " . $error_mail_subject);
+            SyL_Loggers::info("Error mail From: "    . SYL_MAIL_ADMIN_ADDRESS);
             SyL_Loggers::info("Error mail To: "      . SYL_MAIL_ADMIN_ADDRESS);
-            SyL_Loggers::info("Error mail body\n"    . $error_mail_body);
-
-            $types = explode(':', SYL_MAIL_TYPE);
 
             // 顼᡼¹
             include_once SYL_INCLUDE_DIR . '/lib/SyL_Mail.php';
-            $mail =& SyL_Mail::factorySend($types[0]);
-            switch (strtolower($types[0])) {
-            case 'sendmail':
-                if (isset($types[1])) {
-                    $mail->setSendmailPath($types[1]);
-                }
-                break;
-            case 'smtp':
-                if (isset($types[1])) {
-                    $mail->setHost($types[1]);
-                } else {
-                    SyL_Loggers::warn("Mail host not found");
-                }
-                if (isset($types[2])) {
-                    $mail->setPort($types[2]);
-                }
-                break;
-            }
+            $mail =& SyL_Mail::factorySend(SYL_MAIL_TYPE);
             $message =& $mail->createMessage();
             $message->setSubject($error_mail_subject);
             $message->setFrom(SYL_MAIL_ADMIN_ADDRESS);
