@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.16 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.17 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.16 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.17 2008/07/27 14:53:10 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Logger
@@ -93,11 +93,15 @@ class SyL_Logger
      * @param boolean ¨ϥե饰 true: ¨ϡfalse: ꥯȽλ˽
      * @return object ֥
      */
-    function &getLogger($type, $immediate=true)
+    function &getLogger($type='', $immediate=true)
     {
-        // ƥꥪ֥ɤ߹
-        $classname = 'SyL_Logger' . ucfirst($type);
-        include_once SYL_INCLUDE_DIR . "/framework/Logger/{$classname}.php";
+        $logger_object = null;
+        if ($type) {
+            $classname = 'SyL_Logger' . ucfirst($type);
+            include_once SYL_INCLUDE_DIR . "/framework/Logger/{$classname}.php";
+        } else {
+            $classname = 'SyL_Logger';
+        }
         $logger_object =& new $classname($immediate);
         return $logger_object;
     }
