@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.18 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.19 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.18 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.19 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -98,7 +98,7 @@ class SyL_Response
             }
 
             if ($protocol && $server) {
-                if (substr($url, 0, 1) == '/') {
+                if ($url[0] == '/') {
                     $url = "{$protocol}://{$server}{$url}";
                 } else {
                     $path = '';
@@ -146,15 +146,9 @@ class SyL_Response
      *
      * @access public
      */
-    function forward404()
+    function forwardFileNotFound()
     {
-        // Хåե󥰥ꥢ
-        if (!headers_sent() && (ob_get_level() > 0)) {
-            ob_clean();
-        }
-        // ե졼Ȥɽ
-        SyL_Error::forward404();
-        // λ
+        SyL_Error::forwardFileNotFound();
     }
 
     /**
@@ -308,10 +302,8 @@ class SyL_Response
             // ǿMD5
             $data_new_md5 = md5($data);
 
-            // å奯饹
-            include_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
             // å奪֥ȼ
-            $cache =& SyL_Cache::factory(SYL_CACHE);
+            $cache =& SyL_Cache::factory('file');
             $cache->setPrefix('response.');
             $cache->setKey($_SERVER['REQUEST_URI']);
 
