@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.22 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.23 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.22 2008/08/31 13:58:49 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.23 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
@@ -66,6 +66,20 @@ class SyL_Router
      * @var string
      */
     var $exe_ext = '.php';
+    /**
+     * ǥ쥯ȥ롼
+     *
+     * @access private
+     * @var string
+     */
+    var $action_dir = '';
+    /**
+     * ƥץ졼ȥǥ쥯ȥ롼
+     *
+     * @access private
+     * @var string
+     */
+    var $template_dir = '';
     /**
      * ե
      *
@@ -87,13 +101,6 @@ class SyL_Router
      * @var string
      */
     var $action_method = '';
-    /**
-     * 饹̾
-     *
-     * @access protected
-     * @var string
-     */
-    var $action_class = '';
     /**
      * ӥ塼
      *
@@ -117,6 +124,10 @@ class SyL_Router
      */
     function SyL_Router()
     {
+        // ǥ쥯ȥ
+        $this->action_dir = SYL_APP_DIR . '/actions/';
+        // ƥץ졼ȥǥ쥯ȥ
+        $this->template_dir = SYL_APP_DIR . '/templates/';
     }
 
     /**
@@ -124,20 +135,20 @@ class SyL_Router
      *
      * @static
      * @access public
+     * @param object ǡ֥
      * @return object ܾ󥪥֥
      */
-    function &singleton()
+    function &factory(&$data)
     {
-        static $router = null;
-        if ($router === null) {
-            $classname = 'SyL_Router' . ucfirst(SYL_ROUTER_RULE);
-            include_once SYL_INCLUDE_DIR . "/framework/Router/{$classname}.php";
-            $router = new $classname();
-            // եѥå
-            if (!$router->validAction()) {
-                SyL_Response::forward404();
-            }
+        $classname = 'SyL_Router' . ucfirst(SYL_ROUTER_RULE);
+        include_once SYL_INCLUDE_DIR . "/framework/Router/{$classname}.php";
+        $router = new $classname();
+        // եѥå
+        if (!$router->validAction()) {
+            SyL_Response::forwardFileNotFound();
         }
+        $router->createActionInfo($data);
+        $router->changeRoutingConfig();
         return $router;
     }
 
@@ -148,13 +159,49 @@ class SyL_Router
      * $this->action_file
      * $this->action_class
      *
-     * @access protected
+     * @access abstract
      * @param object ǡ֥
      */
     function createActionInfo(&$data)
     {
     }
 
+    /**
+     * ǥ쥯ȥ롼Ȥ
+     *
+     * @access public
+     * @return string ǥ쥯ȥ롼
+     */
+    function getActionDir()
+    {
+        return $this->action_dir;
+    }
+
+    /**
+     * ƥץ졼ȥǥ쥯ȥ롼Ȥ
+     *
+     * @access public
+     * @return string ƥץ졼ȥǥ쥯ȥ롼
+     */
+    function getTemplateDir()
+    {
+        return $this->template_dir;
+    }
+
+    /**
+     * ե򥻥å
+     *
+     * @access public
+     * @param string ե
+     */
+    function setActionFile($action_file)
+    {
+        if ($action_file[0] == '/') {
+            $action_file = substr($action_file, 1);
+        }
+        $this->action_file = $action_file;
+    }
+
     /**
      * ե
      *
@@ -166,14 +213,34 @@ class SyL_Router
         return $this->action_file;
     }
 
+    /**
+     * ƥץ졼ȥե򥻥å
+     *
+     * @access public
+     * @param string ƥץ졼ȥե
+     */
+    function setTemplateFile($template_file)
+    {
+        if ($template_file[0] == '/') {
+            $template_file = substr($template_file, 1);
+        }
+        $this->template_file = $template_file;
+    }
+
     /**
      * ƥץ졼ȥե
      *
      * @access public
+     * @param bool 404顼ưե饰
      * @return string ƥץ졼ȥե
      */
-    function getTemplateFile()
+    function getTemplateFile($trigger_error_404=true)
     {
+        // ƥץ졼ȥե¸ߥå
+        if ($trigger_error_404 && !is_file($this->getTemplateDir() . $this->template_file)) {
+            SyL_Loggers::warn("Template file not found dir: {$template_dir} file: {$template_file}");
+            SyL_Response::forwardFileNotFound();
+        }
         return $this->template_file;
     }
 
@@ -185,7 +252,7 @@ class SyL_Router
      */
     function getClassName()
     {
-        return $this->action_class;
+        return $this->createActionClass();
     }
 
     /**
@@ -199,6 +266,17 @@ class SyL_Router
         return $this->action_method;
     }
 
+    /**
+     * ӥ塼פ򥻥å
+     *
+     * @access public
+     * @param string ӥ塼
+     */
+    function setViewType($view_type)
+    {
+        $this->view_type = $view_type;
+    }
+
     /**
      * ӥ塼פ
      *
@@ -221,6 +299,18 @@ class SyL_Router
         return $this->layout_name;
     }
 
+    /**
+     * 󥯥饹̾
+     *
+     * @access protected
+     * @return string 󥯥饹̾
+     */
+    function createActionClass()
+    {
+        $classname = str_replace('/', '_', $this->action_file);
+        return preg_replace('/(' . preg_quote($this->exe_ext) . ')$/', '', $classname);
+    }
+
     /**
      * 롼ƥŬ
      *
@@ -229,25 +319,18 @@ class SyL_Router
     function changeRoutingConfig()
     {
         $config =& SyL_Config::factory('routers');
+        $config->setRouter($this);
         $config->parseXml();
-        foreach ($config->getConfig() as $action => $router) {
-            $action = str_replace('/', '\\/', $action); 
-            if (preg_match('/^(' . $action . ')$/', $this->action_file)) {
-                if ($router['enableAction']) {
-                    if (isset($router['forwardAction']) && ($router['forwardAction'] !== '')) {
-                        $this->action_file  = $router['forwardAction'];
-                        $this->action_class = $this->createActionClass($this->action_file);
-                    }
-                }
-                if ($router['enableTemplate']) {
-                    if (isset($router['forwardAction']) && ($router['forwardAction'] !== '')) {
-                        $this->template_file = substr($router['forwardAction'], 0, intval('-' . strlen($this->exe_ext))) . SYL_ROUTER_URL_EXT;
-                    }
-                }
-                $this->view_type   = $router['viewType'];
-                $this->layout_name = $router['layoutName'];
-                break;
+        $router = $config->getConfig();
+        if ($router) {
+            if ($router['enableAction'] && $router['forwardAction']) {
+                $this->setActionFile($router['forwardAction']);
             }
+            if ($router['enableTemplate'] && $router['forwardTemplate']) {
+                $this->setTemplateFile($router['forwardTemplate']);
+            }
+            if ($router['viewType'])   $this->view_type   = $router['viewType'];
+            if ($router['layoutName']) $this->layout_name = $router['layoutName'];
         }
     }
 
@@ -261,25 +344,12 @@ class SyL_Router
     function validAction()
     {
         foreach (explode('/', $this->action_file) as $tmp) {
-            if (substr($tmp, 0, 1) == '_') {
+            if ($tmp && ($tmp[0] == '_')) {
                 return false;
             }
         }
         return true;
     }
-
-    /**
-     * 󥯥饹̾
-     *
-     * @access protected
-     * @param string ե
-     * @return string 󥯥饹̾
-     */
-    function createActionClass($action_file)
-    {
-        $classname = str_replace('/', '_', substr($action_file, 1));
-        return preg_replace('/(' . preg_quote($this->exe_ext) . ')$/', '', $classname);
-    }
 }
 
 ?>
