@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayout.php,v 1.10 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayout.php,v 1.11 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayout.php,v 1.10 2008/07/27 14:53:10 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayout.php,v 1.11 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayout extends SyL_View
@@ -71,10 +71,15 @@ class SyL_ViewLayout extends SyL_View
         parent::SyL_View($context, $data);
 
         $config =& SyL_Config::factory('layouts');
-        $config->setContext($context);
+        $config->setRouter($context->getRouter());
         $config->parseXml();
         $this->config = $config->getConfig();
 
+        // ƥץ졼ȥѥ
+        if ($this->config['file'][0] == '/') {
+            $this->config['file'] = substr($this->config['file'], 1);
+        }
+
         // ƥĥפ򥻥å
         $this->setContentType('text/html; charset=' . SYL_ENCODE_INTERNAL);
     }
@@ -105,7 +110,7 @@ class SyL_ViewLayout extends SyL_View
             $values += $this->config['templates'];
         }
         if (isset($this->config['content']) && $this->config['content']) {
-            $values[$this->config['content']] = $this->context->getTemplateFile();
+            $values[$this->config['content']] = $this->router->getTemplateFile();
         } else {
             SyL_Loggers::notice("Content context not found");
         }
