@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.8 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.9 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_ViewLayout.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.8 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.9 2008/11/09 10:05:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayoutDefault extends SyL_ViewLayout
@@ -74,17 +74,6 @@ class SyL_ViewLayoutDefault extends SyL_ViewLayout
         include_once $template_file;
         $this->setRender(ob_get_clean());
     }
-
-    /**
-     * 쥤Υƥץ졼Ȥ򥤥󥯥롼ɤ
-     * 
-     * @access public
-     * @param string 쥤Υƥץ졼
-     */
-    function includeTemplate($template)
-    {
-        include $this->getTemplateDir() . $template;
-    }
 }
 
 ?>
