@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Cache.php,v 1.18 2008/03/29 06:11:46 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Cache.php,v 1.19 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Cache.php,v 1.18 2008/03/29 06:11:46 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Cache.php,v 1.19 2008/11/09 10:05:35 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Cache
@@ -88,6 +88,20 @@ class SyL_Cache
      * @var int
      */
     var $max_mtime = 0; // 0:
+    /**
+     * LbVt@C̊mFCRCt邩
+     *
+     * @access private
+     * @var bool
+     */
+    var $crc = true;
+    /**
+     * LbVt@CVA邩
+     *
+     * @access private
+     * @var bool
+     */
+    var $serial = true;
 
     /**
      * RXgN^
@@ -110,7 +124,7 @@ class SyL_Cache
     {
         $classname = 'SyL_Cache' . ucfirst($type);
         include_once dirname(__FILE__) . "/Cache/{$classname}.php";
-        $obj =& new $classname();
+        $obj = new $classname();
         return $obj;
     }
 
@@ -283,6 +297,61 @@ class SyL_Cache
     {
     }
 
+    /**
+     * CRCǉtOZbg
+     * 
+     * @access public
+     * @param bool CRCǉtO
+     */
+    function setCrc($flag)
+    {
+        $this->crc = (bool)$flag;
+    }
+
+    /**
+     * CRCL
+     * 
+     * @access public
+     * @return bool CRCL
+     */
+    function isCrc()
+    {
+        return $this->crc;
+    }
+
+    /**
+     * CRCǉf[^擾
+     * 
+     * @access public
+     * @param string f[^
+     * @return string nbVl
+     */
+    function getCrc($data)
+    {
+        return sprintf('%+032d', crc32($data));
+    }
+
+    /**
+     * VAtOZbg
+     * 
+     * @access public
+     * @param bool VAtO
+     */
+    function setSerialize($flag)
+    {
+        $this->serial = (bool)$flag;
+    }
+
+    /**
+     * VA
+     * 
+     * @access public
+     * @return bool VA
+     */
+    function isSerialize()
+    {
+        return $this->serial;
+    }
 }
 
 ?>
