@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebService.php,v 1.2 2008/03/01 05:01:22 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebService.php,v 1.3 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -52,7 +52,7 @@ require_once dirname(__FILE__) . '/Http/SyL_HttpClient.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebService.php,v 1.2 2008/03/01 05:01:22 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebService.php,v 1.3 2008/06/20 17:41:54 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_WebService
@@ -86,10 +86,7 @@ class SyL_WebService
      */
     function SyL_WebService()
     {
-        $internal_encode = mb_internal_encoding();
-        if ($internal_encode) {
-            $this->client_encode = $internal_encode;
-        }
+        $this->client_encode = mb_internal_encoding();
     }
 
     /**
