@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.5 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.6 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -51,7 +51,7 @@ require_once dirname(__FILE__) . '/Yahoo_co_jp/SyL_WebServiceYahoo_co_jpResponse
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.5 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.6 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_WebServiceYahoo_co_jp extends SyL_WebService
@@ -473,6 +473,52 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
         $request =& new $class_name();
         return $request;
     }
+
+    // -----------------------------------------------------
+    // Yahoo!åԥ
+    // -----------------------------------------------------
+
+    /**
+     * WEBӥꥯȥ֥Ȥʾʸ
+     * 
+     * @access public
+     * @return object WEBӥꥯȥ֥ȡʾʸ
+     */
+    function &createShoppingItemsearchRequest()
+    {
+        $class_name = 'SyL_WebServiceShoppingItemsearchRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Shopping/Itemsearch/' . $class_name . '.php';
+        $request =& new $class_name();
+        return $request;
+    }
+
+    /**
+     * WEBӥꥯȥ֥Ȥʥƥ󥭥󥰡
+     * 
+     * @access public
+     * @return object WEBӥꥯȥ֥ȡʥƥ󥭥󥰡
+     */
+    function &createShoppingCategoryrankingRequest()
+    {
+        $class_name = 'SyL_WebServiceShoppingCategoryrankingRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Shopping/Categoryranking/' . $class_name . '.php';
+        $request =& new $class_name();
+        return $request;
+    }
+
+    /**
+     * WEBӥꥯȥ֥ȤʥƥID
+     * 
+     * @access public
+     * @return object WEBӥꥯȥ֥ȡʥƥID
+     */
+    function &createShoppingCategorysearchRequest()
+    {
+        $class_name = 'SyL_WebServiceShoppingCategorysearchRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Shopping/Categorysearch/' . $class_name . '.php';
+        $request =& new $class_name();
+        return $request;
+    }
 }
 
 ?>
