@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebServiceMinnaCertCertListResponse.php,v 1.2 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebServiceMinnaCertCertListResponse.php,v 1.3 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebServiceMinnaCertCertListResponse.php,v 1.2 2008/09/11 13:06:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebServiceMinnaCertCertListResponse.php,v 1.3 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_WebServiceMinnaCertCertListResponse extends SyL_WebServiceYahoo_co_jpResponse
@@ -110,6 +110,10 @@ class SyL_WebServiceMinnaCertCertListResponse extends SyL_WebServiceYahoo_co_jpR
         case '/ResultSet/Result/CertId': $this->results[$i]['CertId'] = $text; break;
         // ̾
         case '/ResultSet/Result/CertName': $this->results[$i]['CertName'] = $text; break;
+        // ʬ
+        case '/ResultSet/Result/CertDiv': $this->results[$i]['CertDiv'] = $text; break;
+        // 
+        case '/ResultSet/Result/UserName': $this->results[$i]['UserName'] = $text; break;
         // URL
         case '/ResultSet/Result/CertImageUrl': $this->results[$i]['CertImageUrl'] = $text; break;
         // 공
@@ -118,6 +122,8 @@ class SyL_WebServiceMinnaCertCertListResponse extends SyL_WebServiceYahoo_co_jpR
         case '/ResultSet/Result/OpenDate': $this->results[$i]['OpenDate'] = $text; break;
         // 
         case '/ResultSet/Result/QuestionCount': $this->results[$i]['QuestionCount'] = $text; break;
+        // ݡȸե饰
+        case '/ResultSet/Result/ReportOpenFlag': $this->results[$i]['ReportOpenFlag'] = $text; break;
         // ʴ
         case '/ResultSet/Result/Correct': $this->results[$i]['Correct'] = $text; break;
         // 
