@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.3 2008/09/23 09:06:16 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.4 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -52,7 +52,7 @@ SyL_Loader::lib('Mail');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.3 2008/09/23 09:06:16 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.4 2008/09/29 14:41:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
@@ -106,19 +106,21 @@ class Index extends AppAction
         $end_date       = null;
 
         // ץå
-        $syslog = false;
+        $syslog_only = false;
+        $mail   = false;
         switch ($type) {
         case 'view':
         case 'archive':
         case 'remove':
-            $syslog = false;
+            $syslog_only = false;
             break;
         case 'sysview':
         case 'sysarchive':
         case 'sysremove':
-            $syslog = true;
+            $syslog_only = true;
             break;
         case 'mail':
+            $mail = true;
             break;
         default:
             $this->displayDefault($cmd, $data->get(0));
@@ -189,13 +191,16 @@ class Index extends AppAction
         // -------------------------------------------------
         foreach ($app_names as $app_name) {
             $tmp_logfiles = array();
+            $mail_type    = '';
+            $mail_address = '';
+
             // ƥ
-            if ($syslog || $include_syslog) {
+            if ($syslog_only || $include_syslog) {
                 $logfile = "{$project_dir}/var/syslogs/{$app_name}/phperror_{YYYY}{MM}{DD}.log";
                 $tmp_logfiles[] = array($logfile, true);
             }
             // SyL
-            if (!$syslog) {
+            if (!$syslog_only) {
                 // ե뤫
                 $project_config_file = "{$project_dir}config/defines.xml";
                 $app_config_file     = "{$project_dir}apps/{$app_name}/config/defines.xml";
@@ -210,16 +215,21 @@ class Index extends AppAction
                 $config->parseXml(false, false);
                 $values = $config->getConfig();
 
-                if (!isset($values['SYL_LOG_FILE']) || !$values['SYL_LOG_FILE']) {
-                    trigger_error("[SyL error] `SYL_LOG_FILE' constant not defined in config file({$project_config_file} or {$app_config_file})", E_USER_ERROR);
-                }
                 $logfile = $values['SYL_LOG_FILE'];
                 $logfile = str_replace('{SYL_PROJECT_DIR}', $project_dir, $logfile);
                 $logfile = str_replace('{SYL_APP_NAME}',    $app_name,    $logfile);
+                if ($mail) {
+                    $mail_type    = $values['SYL_MAIL_TYPE'];
+                    $mail_address = $values['SYL_MAIL_ADMIN_ADDRESS'];
+                }
                 $tmp_logfiles[] = array($logfile, false);
             }
+
             // ʪեꥹȼ
-            $logfiles = array_merge($logfiles, $this->getLogfiles($tmp_logfiles, $start_date, $end_date));
+            $logfiles[$app_name]['files'] = $this->getLogfiles($tmp_logfiles, $start_date, $end_date);
+            $logfiles[$app_name]['mail']  = $mail;
+            $logfiles[$app_name]['mail_type']    = $mail_type;
+            $logfiles[$app_name]['mail_address'] = $mail_address;
         }
 
         // -------------------------------------------------
@@ -255,11 +265,7 @@ class Index extends AppAction
                   exit;
                 }
             }
-            if ($type == 'mail') {
-                $this->mailLog($cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime);
-            } else {
-                $this->viewLog($cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime);
-            }
+            $this->viewLog($cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime);
             break;
         case 'remove':
         case 'sysremove':
@@ -288,9 +294,7 @@ class Index extends AppAction
             $logfile_name = str_replace('\\{DD\\}',   '\\d{2}', $logfile_name);
             $logfile_name_reg = '/^' . $logfile_name . '(\.gz)?$/';
 
-            $dir =& SyL_Filesystem::factory($logfile_dir);
-            $dir->createTree();
-            foreach ($dir->getList() as $element) {
+            foreach (SyL_Filesystem::getFiles($logfile_dir, false, true) as $element) {
                 // ֥ե륿
                 $mtime = $element->getMtime();
                 if ($start_date && ($mtime < $start_date)) continue;
@@ -298,6 +302,11 @@ class Index extends AppAction
                 // ե̾ե륿
                 $filename = $element->getName();
                 if (!preg_match($logfile_name_reg, basename($filename))) continue;
+                // 0 ХȥեϺ
+                if ($element->getSize() == 0) {
+                    SyL_Filesystem::remove($filename);
+                    continue;
+                }
                 $logfiles[] = array($filename, $tmp_logfile[1]);
             }
         }
@@ -315,22 +324,26 @@ class Index extends AppAction
      */
     function archiveLog(&$cmd, $logfiles, $output_dir, $remove_log)
     {
-        foreach ($logfiles as $logfile) {
-            if (!preg_match('/\.gz$/', $logfile[0]) && (filesize($logfile[0]) > 0)) {
-                $output_file = '';
-                if ($output_dir) {
-                    $output_file = $output_dir . '/' . basename($logfile[0]) . '.gz';
-                } else {
-                    $output_file = $logfile[0] . '.gz';
+        foreach ($logfiles as $app_name => $values) {
+            foreach ($values['files'] as $logfile) {
+                if (!preg_match('/\.gz$/', $logfile[0]) && (filesize($logfile[0]) > 0)) {
+                    $mtime = filemtime($logfile[0]);
+                    $output_file = '';
+                    if ($output_dir) {
+                        $output_file = $output_dir . '/' . basename($logfile[0]) . '.gz';
+                    } else {
+                        $output_file = $logfile[0] . '.gz';
+                    }
+                    SyL_Compress::compressFromFile('gzip', $logfile[0], $output_file, $remove_log);
+                    @touch($output_file, $mtime);
+                    $cmd->stdout("{$logfile[0]} -> {$output_file}");
                 }
-                SyL_Compress::compressFromFile('gzip', $logfile[0], $output_file, $remove_log);
-                $cmd->stdout("{$logfile[0]} -> {$output_file}");
             }
         }
     }
 
     /**
-     * Ƥɽ
+     * Ƥɽ᡼
      *
      * @access private
      * @param object ޥɥ֥
@@ -339,9 +352,8 @@ class Index extends AppAction
      * @param bool ꥫƥΤɽե饰
      * @param string 
      * @param string λ
-     * @param bool echoϥե饰
      */
-    function viewLog(&$cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime, $echo=false)
+    function viewLog(&$cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime)
     {
         $categories = array(
             'none'   => SYL_LOG_NONE,
@@ -353,76 +365,84 @@ class Index extends AppAction
          );
         $current_category = $category_name ? $categories[$category_name] : null;
 
-        foreach ($logfiles as $logfile) {
-            $reg = '';
-            if ($logfile[1]) {
-                $reg = '/^\[([^\]]+)\] PHP.* (error|Warning|Notice): .+/';
-            } else {
-                $reg = '/^(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}) \[[^\]]+:([^\]]+)\] .+/';
-            }
+        foreach ($logfiles as $app_name => $values) {
+            $contents = '';
+            foreach ($values['files'] as $logfile) {
+                $reg = '';
+                if ($logfile[1]) {
+                    $reg = '/^\[([^\]]+)\] PHP.* (error|Warning|Notice): .+/';
+                } else {
+                    $reg = '/^(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}) \[[^\]]+:([^\]]+)\] .+/';
+                }
 
-            $fp = null;
-            if (preg_match('/\.gz$/', $logfile[0])) {
-                $fp = fopen("compress.zlib://{$logfile[0]}", 'rb');
-            } else {
-                $fp = fopen($logfile[0], 'rb');
-            }
-            $line = '';
-            $tmp_category = '';
-            while (!feof($fp)) {
-                $tmp = fgets($fp);
-                if (preg_match($reg, $tmp, $matches)) {
-                    if ($line) {
-                        if ($echo) {
-                            echo rtrim($line)."\n";
-                        } else {
-                            $cmd->stdout(rtrim($line));
+                $fp = null;
+                if (preg_match('/\.gz$/', $logfile[0])) {
+                    $fp = fopen("compress.zlib://{$logfile[0]}", 'rb');
+                } else {
+                    $fp = fopen($logfile[0], 'rb');
+                }
+                $line = '';
+                $tmp_category = '';
+                while (!feof($fp)) {
+                    $tmp = fgets($fp);
+                    if (preg_match($reg, $tmp, $matches)) {
+                        if ($line) {
+                            if ($values['mail']) {
+                                $contents .= rtrim($line)."\n";
+                            } else {
+                                $cmd->stdout(rtrim($line));
+                            }
                         }
-                    }
 
-                    $skip = false;
-                    $current_datetime = strtotime($matches[1]);
-                    if ($start_datetime && ($current_datetime < $start_datetime)) {
-                        $skip = true;
-                    }
-                    if ($end_datetime && ($current_datetime > $end_datetime)) {
-                        $skip = true;
-                    }
-
-                    if (!$skip) {
-                        // syslog
-                        $matches[2] = strtolower($matches[2]);
-                        if ($matches[2] == 'warning') {
-                            $matches[2] = 'warn';
+                        $skip = false;
+                        $current_datetime = strtotime($matches[1]);
+                        if ($start_datetime && ($current_datetime < $start_datetime)) {
+                            $skip = true;
                         }
-                        if (!$current_category) {
-                            $line = $tmp;
-                        } else if ($category_only && ($categories[$matches[2]] == $current_category)) {
-                            $line = $tmp;
-                        } else if (!$category_only && ($categories[$matches[2]] <= $current_category)) {
-                            $line = $tmp;
-                        } else {
+                        if ($end_datetime && ($current_datetime > $end_datetime)) {
                             $skip = true;
                         }
-                    }
 
-                    if ($skip) {
-                        $line = '';
-                    }
-                } else {
-                    if ($line) {
-                        $line .= $tmp;
+                        if (!$skip) {
+                            // syslog
+                            $matches[2] = strtolower($matches[2]);
+                            if ($matches[2] == 'warning') {
+                                $matches[2] = 'warn';
+                            }
+                            if (!$current_category) {
+                                $line = $tmp;
+                            } else if ($category_only && ($categories[$matches[2]] == $current_category)) {
+                                $line = $tmp;
+                            } else if (!$category_only && ($categories[$matches[2]] <= $current_category)) {
+                                $line = $tmp;
+                            } else {
+                                $skip = true;
+                            }
+                        }
+
+                        if ($skip) {
+                            $line = '';
+                        }
+                    } else {
+                        if ($line) {
+                            $line .= $tmp;
+                        }
                     }
                 }
-            }
-            if ($line) {
-                if ($echo) {
-                    echo rtrim($line)."\n";
-                } else {
-                    $cmd->stdout(rtrim($line));
+                if ($line) {
+                    if ($values['mail']) {
+                        $contents .= rtrim($line)."\n";
+                    } else {
+                        $cmd->stdout(rtrim($line));
+                    }
                 }
+                fclose($fp);
+            }
+
+            // ᡼Ƚ
+            if ($contents) {
+                $this->sendmail($values['mail_type'], $values['mail_address'], $contents, $start_datetime, $end_datetime);
             }
-            fclose($fp);
         }
     }
 
@@ -435,9 +455,11 @@ class Index extends AppAction
      */
     function removeLog(&$cmd, $logfiles)
     {
-        foreach ($logfiles as $logfile) {
-            if (unlink($logfile[0])) {
-                $cmd->stdout("remove: {$logfile[0]}");
+        foreach ($logfiles as $app_name => $values) {
+            foreach ($values['files'] as $logfile) {
+                if (unlink($logfile[0])) {
+                    $cmd->stdout("remove: {$logfile[0]}");
+                }
             }
         }
     }
@@ -446,52 +468,46 @@ class Index extends AppAction
      * Ƥ᡼
      *
      * @access private
-     * @param object ޥɥ֥
-     * @param array ե
-     * @param string ƥ̾
-     * @param bool ꥫƥΤɽե饰
+     * @param string ᡼륿
+     * @param string ᡼륢ɥ쥹
+     * @param string ᡼
      * @param string 
      * @param string λ
      */
-    function mailLog(&$cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime)
+    function sendmail($mail_type, $mail_address, $contents, $start_datetime, $end_datetime)
     {
-        ob_start();
-        $this->viewLog($cmd, $logfiles, $category_name, $category_only, $start_datetime, $end_datetime, true);
-        $contents = ob_get_clean();
+        if (!$mail_type || !$mail_address) {
+            SyL_Loggers::warn("[SyL error] `SYL_MAIL_TYPE' or 'SYL_MAIL_ADMIN_ADDRESS' Constant not defined");
+            return;
+        }
 
-        if ($contents) {
-            if (!defined('SYL_MAIL_TYPE') || !defined('SYL_MAIL_ADMIN_ADDRESS') ||
-                !SYL_MAIL_TYPE || !SYL_MAIL_ADMIN_ADDRESS) {
-                trigger_error("[SyL error] `SYL_MAIL_TYPE' or 'SYL_MAIL_ADMIN_ADDRESS' Constant not defined", E_USER_ERROR);
-            }
+        $start_date = null;
+        $end_date   = null;
+        if ($start_datetime) $start_date = date('Y/m/d', $start_datetime);
+        if ($end_datetime)   $end_date   = date('Y/m/d', $end_datetime);
 
-            $start_date = null;
-            $end_date   = null;
-            if ($start_datetime) $start_date = date('Y/m/d', $start_datetime);
-            if ($end_datetime)   $end_date   = date('Y/m/d', $end_datetime);
-
-            // ᡼륿ȥղ
-            $mail_title = '';
-            if ($start_date == $end_date) {
-                if ($start_date == null) {
-                    $mail_title = $this->mail_title;
-                } else {
-                    $mail_title = "{$this->mail_title} ({$start_date})";
-                }
+        // ᡼륿ȥղ
+        $mail_title = '';
+        if ($start_date == $end_date) {
+            if ($start_date == null) {
+                $mail_title = $this->mail_title;
             } else {
-                $mail_title = "{$this->mail_title} ({$start_date} - {$end_date})";
+                $mail_title = "{$this->mail_title} ({$start_date})";
             }
+        } else {
+            $mail_title = "{$this->mail_title} ({$start_date} - {$end_date})";
+        }
 
-            // ¹
-            $date = date('Y-m-d H:i:s');
-            // SyLΥС
-            $version     = SYL_VERSION;
-            $version_php = PHP_VERSION;
-            $uname       = php_uname();
-            // ᡼ʸ
-            $contents = substr($contents, 0, $this->mail_max_log_size);
+        // ¹
+        $date = date('Y-m-d H:i:s');
+        // SyLΥС
+        $version     = SYL_VERSION;
+        $version_php = PHP_VERSION;
+        $uname       = php_uname();
+        // ᡼ʸ
+        $contents = substr($contents, 0, $this->mail_max_log_size);
 
-            $contents = <<< EOF
+        $contents = <<< EOF
 SyL Framework Log info. {$date}
 ----------------------------------------
 
@@ -502,16 +518,15 @@ SyL Framework ver. {$version} on PHP {$version_php}
 {$uname}
 EOF;
 
-            // ᡼¹
-            $mail =& SyL_Mail::factorySend(SYL_MAIL_TYPE);
-            $message =& $mail->createMessage();
-            $message->setSubject($mail_title);
-            $message->setFrom(SYL_MAIL_ADMIN_ADDRESS);
-            $message->addTo(SYL_MAIL_ADMIN_ADDRESS);
-            $message->setBody($contents);
-            if (!$mail->send($message)) {
-                trigger_error("[SyL error] Can not Send mail. " . $mail->getErrorMessage(), E_USER_ERROR);
-            }
+        // ᡼¹
+        $mail =& SyL_Mail::factorySend($mail_type);
+        $message =& $mail->createMessage();
+        $message->setSubject($mail_title);
+        $message->setFrom($mail_address);
+        $message->addTo($mail_address);
+        $message->setBody($contents);
+        if (!$mail->send($message)) {
+            SyL_Loggers::warn("[SyL error] Can not Send mail: " . $mail->getErrorMessage());
         }
     }
 
